@@ -5,10 +5,10 @@ use Moose;
 extends 'Webservice::InterMine::Constraint';
 with 'Webservice::InterMine::Constraint::Role::Operator';
 
-use InterMine::TypeLibrary qw(MultiOperator);
+use Webservice::InterMine::Types qw(MultiOperator);
 use MooseX::Types::Moose qw(ArrayRef Str);
 
-has '+op' => ( isa => MultiOperator, );
+has '+op' => ( isa => MultiOperator, coerce => 1 );
 
 has 'values' => (
     is       => 'ro',
